# Settings

Table 1. Quick reference for section “general”
Setting | Description
--- | ---
ignore-case | Whether to find text on a page case-insensitively.
wrap-search | Whether to wrap finding text to the top when arriving at the end.
startpage | The default page(s) to open at the start, separated by commas.
auto-search | Whether to start a search when something else than a URL is entered.
auto-save-config | Whether to save the config automatically on quit.
editor | The editor (and arguments) to use for the `open-editor` command.
editor-encoding | Encoding to use for editor.
private-browsing | Do not record visited pages in the history or store web page icons.
developer-extras | Enable extra tools for Web developers.
print-element-backgrounds | Whether the background color and images are also drawn when the page is printed.
xss-auditing | Whether load requests should be monitored for cross-site scripting attempts.
site-specific-quirks | Enable workarounds for broken sites.
default-encoding | Default encoding to use for websites.
new-instance-open-target | How to open links in an existing instance if a new one is launched.

Table 2. Quick reference for section “ui”
Setting | Description
--- | ---
zoom-levels | The available zoom levels, separated by commas.
default-zoom | The default zoom level.
message-timeout | Time (in ms) to show messages in the statusbar for.
confirm-quit | Whether to confirm quitting the application.
display-statusbar-messages | Whether to display javascript statusbar messages.
zoom-text-only | Whether the zoom factor on a frame applies only to the text or to all content.
frame-flattening | Whether to expand each subframe to its contents.
user-stylesheet | User stylesheet to use (absolute filename or CSS string).
css-media-type | Set the CSS media type.
remove-finished-downloads | Whether to remove finished downloads automatically.

Table 3. Quick reference for section “network”
Setting | Description
--- | ---
do-not-track | Value to send in the `DNT` header.
accept-language | Value to send in the `accept-language` header.
user-agent | User agent to send. Empty to send the default.
proxy | The proxy to use.
ssl-strict | Whether to validate SSL handshakes.
dns-prefetch | Whether to try to pre-fetch DNS entries to speed up browsing.

Table 4. Quick reference for section “completion”
Setting | Description
--- | ---
show | Whether to show the autocompletion window.
height | The height of the completion, in px or as percentage of the window.
history-length | How many commands to save in the history.
quick-complete | Whether to move on to the next part when there’s only one possible completion left.
shrink | Whether to shrink the completion to be smaller than the configured size if there are no scrollbars.

Table 5. Quick reference for section “input”
Setting | Description
--- | ---
timeout | Timeout for ambiguous keybindings.
insert-mode-on-plugins | Whether to switch to insert mode when clicking flash and other plugins.
auto-leave-insert-mode | Whether to leave insert mode if a non-editable element is clicked.
auto-insert-mode | Whether to automatically enter insert mode if an editable element is focused after page load.
forward-unbound-keys | Whether to forward unbound keys to the webview in normal mode.
spatial-navigation | Enables or disables the Spatial Navigation feature
links-included-in-focus-chain | Whether hyperlinks should be included in the keyboard focus chain.

Table 6. Quick reference for section “tabs”
Setting | Description
--- | ---
background-tabs | Whether to open new tabs (middleclick/ctrl+click) in background.
select-on-remove | Which tab to select when the focused tab is removed.
new-tab-position | How new tabs are positioned.
new-tab-position-explicit | How new tabs opened explicitely are positioned.
last-close | Behaviour when the last tab is closed.
auto-hide | Hide the tabbar if only one tab is open.
wrap | Whether to wrap when changing tabs.
movable | Whether tabs should be movable.
close-mouse-button | On which mouse button to close tabs.
position | The position of the tab bar.
show-favicons | Whether to show favicons in the tab bar.
width | The width of the tab bar if it’s vertical, in px or as percentage of the window.
indicator-width | Width of the progress indicator (0 to disable).
indicator-space | Spacing between tab edge and indicator.
tabs-are-windows | Whether to open windows instead of tabs.

Table 7. Quick reference for section “storage”
Setting | Description
--- | ---
download-directory | The directory to save downloads to. An empty value selects a sensible os-specific default.
maximum-pages-in-cache | The maximum number of pages to hold in the memory page cache.
object-cache-capacities | The capacities for the memory cache for dead objects such as stylesheets or scripts. Syntax: cacheMinDeadCapacity, cacheMaxDead, totalCapacity.
offline-storage-default-quota | Default quota for new offline storage databases.
offline-web-application-cache-quota | Quota for the offline web application cache.
offline-storage-database | Whether support for the HTML 5 offline storage feature is enabled.
offline-web-application-storage | Whether support for the HTML 5 web application cache feature is enabled.
local-storage | Whether support for the HTML 5 local storage feature is enabled.
cache-size | Size of the HTTP network cache.

Table 8. Quick reference for section “content”
Setting | Description
--- | ---
allow-images | Whether images are automatically loaded in web pages.
allow-javascript | Enables or disables the running of JavaScript programs.
allow-plugins | Enables or disables plugins in Web pages.
javascript-can-open-windows | Whether JavaScript programs can open new windows.
javascript-can-close-windows | Whether JavaScript programs can close windows.
javascript-can-access-clipboard | Whether JavaScript programs can read or write to the clipboard.
local-content-can-access-remote-urls | Whether locally loaded documents are allowed to access remote urls.
local-content-can-access-file-urls | Whether locally loaded documents are allowed to access other local urls.
cookies-accept | Whether to accept cookies.
cookies-store | Whether to store cookies.
host-block-lists | List of URLs of lists which contain hosts to block.

Table 9. Quick reference for section “hints”
Setting | Description
--- | ---
border | CSS border value for hints.
opacity | Opacity for hints.
mode | Mode to use for hints.
chars | Chars used for hint strings.
uppercase | Make chars in hint strings uppercase.
auto-follow | Whether to auto-follow a hint if there’s only one left.
next-regexes | A comma-separated list of regexes to use for next links.
prev-regexes | A comma-separated list of regexes to use for prev links.

Table 10. Quick reference for section “colors”
Setting | Description
--- | ---
completion.fg | Text color of the completion widget.
completion.bg | Background color of the completion widget.
completion.item.bg | Background color of completion widget items.
completion.category.fg | Foreground color of completion widget category headers.
completion.category.bg | Background color of the completion widget category headers.
completion.category.border.top | Top border color of the completion widget category headers.
completion.category.border.bottom | Bottom border color of the completion widget category headers.
completion.item.selected.fg | Foreground color of the selected completion item.
completion.item.selected.bg | Background color of the selected completion item.
completion.item.selected.border.top | Top border color of the completion widget category headers.
completion.item.selected.border.bottom | Bottom border color of the selected completion item.
completion.match.fg | Foreground color of the matched text in the completion.
statusbar.bg | Foreground color of the statusbar.
statusbar.fg | Foreground color of the statusbar.
statusbar.bg.error | Background color of the statusbar if there was an error.
statusbar.bg.prompt | Background color of the statusbar if there is a prompt.
statusbar.bg.insert | Background color of the statusbar in insert mode.
statusbar.progress.bg | Background color of the progress bar.
statusbar.url.fg | Default foreground color of the URL in the statusbar.
statusbar.url.fg.success | Foreground color of the URL in the statusbar on successful load.
statusbar.url.fg.error | Foreground color of the URL in the statusbar on error.
statusbar.url.fg.warn | Foreground color of the URL in the statusbar when there’s a warning.
statusbar.url.fg.hover | Foreground color of the URL in the statusbar for hovered links.
tabs.fg.odd | Foreground color of unselected odd tabs.
tabs.fg.even | Foreground color of unselected even tabs.
tabs.fg.selected | Foreground color of selected tabs.
tabs.bg.odd | Background color of unselected odd tabs.
tabs.bg.even | Background color of unselected even tabs.
tabs.bg.selected | Background color of selected tabs.
tabs.bg.bar | Background color of the tabbar.
tabs.indicator.start | Color gradient start for the tab indicator.
tabs.indicator.stop | Color gradient end for the tab indicator.
tabs.indicator.error | Color for the tab indicator on errors..
tabs.indicator.system | Color gradient interpolation system for the tab indicator.
tabs.seperator | Color for the tab seperator.
hints.fg | Font color for hints.
hints.fg.match | Font color for the matched part of hints.
hints.bg | Background color for hints.
downloads.fg | Foreground color for downloads.
downloads.bg.bar | Background color for the download bar.
downloads.bg.start | Color gradient start for downloads.
downloads.bg.stop | Color gradient end for downloads.
downloads.bg.system | Color gradient interpolation system for downloads.
downloads.bg.error | Background color for downloads with errors.

Table 11. Quick reference for section “fonts”
Setting | Description
--- | ---
_monospace | Default monospace fonts.
completion | Font used in the completion widget.
tabbar | Font used in the tabbar.
statusbar | Font used in the statusbar.
downloads | Font used for the downloadbar.
hints | Font used for the hints.
debug-console | Font used for the debugging console.
web-family-standard | Font family for standard fonts.
web-family-fixed | Font family for fixed fonts.
web-family-serif | Font family for serif fonts.
web-family-sans-serif | Font family for sans-serif fonts.
web-family-cursive | Font family for cursive fonts.
web-family-fantasy | Font family for fantasy fonts.
web-size-minimum | The hard minimum font size.
web-size-minimum-logical | The minimum logical font size that is applied when zooming out.
web-size-default | The default font size for regular text.
web-size-default-fixed | The default font size for fixed-pitch text.

## general

General/miscellaneous options.

### ignore-case

Whether to find text on a page case-insensitively.

Valid values:

- `true`: Search case-insensitively

- `false`: Search case-sensitively

- `smart`: Search case-sensitively if there are capital chars

Default: `smart`

### wrap-search

Whether to wrap finding text to the top when arriving at the end.

Valid values:

- `true`

- `false`

Default: `true`

### startpage

The default page(s) to open at the start, separated by commas.

Default: `https://www.duckduckgo.com`

### auto-search

Whether to start a search when something else than a URL is entered.

Valid values:

- `naive`: Use simple/naive check.

- `dns`: Use DNS requests (might be slow!).

- `false`: Never search automatically.

Default: `naive`

### auto-save-config

Whether to save the config automatically on quit.

Valid values:

- `true`

- `false`

Default: `true`

### editor

The editor (and arguments) to use for the `open-editor` command.

Use `{}` for the filename. The value gets split like in a shell, so you can use `"` or `'` to quote arguments.

Default: `gvim -f "{}"`

### editor-encoding

Encoding to use for editor.

Default: `utf-8`

### private-browsing

Do not record visited pages in the history or store web page icons.

Valid values:

- `true`

- `false`

Default: `false`

### developer-extras

Enable extra tools for Web developers.

This needs to be enabled for `:inspector` to work and also adds an Inspect entry to the context menu.

Valid values:

- `true`

- `false`

Default: `false`

### print-element-backgrounds

Whether the background color and images are also drawn when the page is printed.

Valid values:

- `true`

- `false`

Default: `true`

### xss-auditing

Whether load requests should be monitored for cross-site scripting attempts.

Suspicious scripts will be blocked and reported in the inspector’s JavaScript console. Enabling this feature might have an impact on performance.

Valid values:

- `true`

- `false`

Default: `false`

### site-specific-quirks

Enable workarounds for broken sites.

Valid values:

- `true`

- `false`

Default: `true`

### default-encoding

Default encoding to use for websites.

The encoding must be a string describing an encoding such as utf-8, iso-8859-1, etc. If left empty a default value will be used.

Default: empty

### new-instance-open-target

How to open links in an existing instance if a new one is launched.

Valid values:

- `tab`: Open a new tab in the existing window and activate it.

- `tab-silent`: Open a new tab in the existing window without activating it.

- `window`: Open in a new window.

Default: `window`

## ui

General options related to the user interface.

### zoom-levels

The available zoom levels, separated by commas.

Default: `25%,33%,50%,67%,75%,90%,100%,110%,125%,150%,175%,200%,250%,300%,400%,500%`

### default-zoom

The default zoom level.

Default: `100%`

### message-timeout

Time (in ms) to show messages in the statusbar for.

Default: `2000`

### confirm-quit

Whether to confirm quitting the application.

Valid values:

- `always`: Always show a confirmation.

- `multiple-tabs`: Show a confirmation if multiple tabs are opened.

- `never`: Never show a confirmation.

Default: `never`

### display-statusbar-messages

Whether to display javascript statusbar messages.

Valid values:

- `true`

- `false`

Default: `false`

### zoom-text-only

Whether the zoom factor on a frame applies only to the text or to all content.

Valid values:

- `true`

- `false`

Default: `false`

### frame-flattening

Whether to expand each subframe to its contents.

This will flatten all the frames to become one scrollable page.

Valid values:

- `true`

- `false`

Default: `false`

### user-stylesheet

User stylesheet to use (absolute filename or CSS string).

Default: `::-webkit-scrollbar { width: 0px; height: 0px; }`

### css-media-type

Set the CSS media type.

Default: empty

### remove-finished-downloads

Whether to remove finished downloads automatically.

Valid values:

- `true`

- `false`

Default: `false`

## network

Settings related to the network.

### do-not-track

Value to send in the `DNT` header.

Valid values:

- `true`

- `false`

Default: `true`

### accept-language

Value to send in the `accept-language` header.

Default: `en-US,en`

### user-agent

User agent to send. Empty to send the default.

Default: empty

### proxy

The proxy to use.

In addition to the listed values, you can use a `socks://...` or `http://...` URL.

Valid values:

- `system`: Use the system wide proxy.

- `none`: Don’t use any proxy

Default: `system`

### ssl-strict

Whether to validate SSL handshakes.

Valid values:

- `true`

- `false`

- `ask`

Default: `ask`

### dns-prefetch

Whether to try to pre-fetch DNS entries to speed up browsing.

Valid values:

- `true`

- `false`

Default: `true`

## completion

Options related to completion and command history.

### show

Whether to show the autocompletion window.

Valid values:

- `true`

- `false`

Default: `true`

### height

The height of the completion, in px or as percentage of the window.

Default: `50%`

### history-length

How many commands to save in the history.

0: no history / -1: unlimited

Default: `100`

### quick-complete

Whether to move on to the next part when there’s only one possible completion left.

Valid values:

- `true`

- `false`

Default: `true`

### shrink

Whether to shrink the completion to be smaller than the configured size if there are no scrollbars.

Valid values:

- `true`

- `false`

Default: `false`

## input

Options related to input modes.

### timeout

Timeout for ambiguous keybindings.

Default: `500`

### insert-mode-on-plugins

Whether to switch to insert mode when clicking flash and other plugins.

Valid values:

- `true`

- `false`

Default: `false`

### auto-leave-insert-mode

Whether to leave insert mode if a non-editable element is clicked.

Valid values:

- `true`

- `false`

Default: `true`

### auto-insert-mode

Whether to automatically enter insert mode if an editable element is focused after page load.

Valid values:

- `true`

- `false`

Default: `false`

### forward-unbound-keys

Whether to forward unbound keys to the webview in normal mode.

Valid values:

- `all`: Forward all unbound keys.

- `auto`: Forward unbound non-alphanumeric keys.

- `none`: Don’t forward any keys.

Default: `auto`

### spatial-navigation

Enables or disables the Spatial Navigation feature

Spatial navigation consists in the ability to navigate between focusable elements in a Web page, such as hyperlinks and form controls, by using Left, Right, Up and Down arrow keys. For example, if a user presses the Right key, heuristics determine whether there is an element he might be trying to reach towards the right and which element he probably wants.

Valid values:

- `true`

- `false`

Default: `false`

### links-included-in-focus-chain

Whether hyperlinks should be included in the keyboard focus chain.

Valid values:

- `true`

- `false`

Default: `true`

## tabs

Configuration of the tab bar.

### background-tabs

Whether to open new tabs (middleclick/ctrl+click) in background.

Valid values:

- `true`

- `false`

Default: `false`

### select-on-remove

Which tab to select when the focused tab is removed.

Valid values:

- `left`: Select the tab on the left.

- `right`: Select the tab on the right.

- `previous`: Select the previously selected tab.

Default: `right`

### new-tab-position

How new tabs are positioned.

Valid values:

- `left`: On the left of the current tab.

- `right`: On the right of the current tab.

- `first`: At the left end.

- `last`: At the right end.

Default: `right`

### new-tab-position-explicit

How new tabs opened explicitely are positioned.

Valid values:

- `left`: On the left of the current tab.

- `right`: On the right of the current tab.

- `first`: At the left end.

- `last`: At the right end.

Default: `last`

### last-close

Behaviour when the last tab is closed.

Valid values:

- `ignore`: Don’t do anything.

- `blank`: Load a blank page.

- `close`: Close the window.

Default: `ignore`

### auto-hide

Hide the tabbar if only one tab is open.

Valid values:

- `true`

- `false`

Default: `false`

### wrap

Whether to wrap when changing tabs.

Valid values:

- `true`

- `false`

Default: `true`

### movable

Whether tabs should be movable.

Valid values:

- `true`

- `false`

Default: `true`

### close-mouse-button

On which mouse button to close tabs.

Valid values:

- `right`: Close tabs on right-click.

- `middle`: Close tabs on middle-click.

- `none`: Don’t close tabs using the mouse.

Default: `middle`

### position

The position of the tab bar.

Valid values:

- `north`

- `south`

- `east`

- `west`

Default: `north`

### show-favicons

Whether to show favicons in the tab bar.

Valid values:

- `true`

- `false`

Default: `true`

### width

The width of the tab bar if it’s vertical, in px or as percentage of the window.

Default: `20%`

### indicator-width

Width of the progress indicator (0 to disable).

Default: `3`

### indicator-space

Spacing between tab edge and indicator.

Default: `3`

### tabs-are-windows

Whether to open windows instead of tabs.

Valid values:

- `true`

- `false`

Default: `false`

## storage

Settings related to cache and storage.

### download-directory

The directory to save downloads to. An empty value selects a sensible os-specific default.

Default: empty

### maximum-pages-in-cache

The maximum number of pages to hold in the memory page cache.

The Page Cache allows for a nicer user experience when navigating forth or back to pages in the forward/back history, by pausing and resuming up to n pages.

For more information about the feature, please refer to: http://webkit.org/blog/427/webkit-page-cache-i-the-basics/

Default: empty

### object-cache-capacities

The capacities for the memory cache for dead objects such as stylesheets or scripts. Syntax: cacheMinDeadCapacity, cacheMaxDead, totalCapacity.

The cacheMinDeadCapacity specifies the minimum number of bytes that dead objects should consume when the cache is under pressure.

cacheMaxDead is the maximum number of bytes that dead objects should consume when the cache is not under pressure.

totalCapacity specifies the maximum number of bytes that the cache should consume overall.

Default: empty

### offline-storage-default-quota

Default quota for new offline storage databases.

Default: empty

### offline-web-application-cache-quota

Quota for the offline web application cache.

Default: empty

### offline-storage-database

Whether support for the HTML 5 offline storage feature is enabled.

Valid values:

- `true`

- `false`

Default: `true`

### offline-web-application-storage

Whether support for the HTML 5 web application cache feature is enabled.

An application cache acts like an HTTP cache in some sense. For documents that use the application cache via JavaScript, the loader engine will first ask the application cache for the contents, before hitting the network.

The feature is described in details at: http://dev.w3.org/html5/spec/Overview.html#appcache

Valid values:

- `true`

- `false`

Default: `true`

### local-storage

Whether support for the HTML 5 local storage feature is enabled.

Valid values:

- `true`

- `false`

Default: `true`

### cache-size

Size of the HTTP network cache.

Default: `52428800`

## content

Loaded plugins/scripts and allowed actions.

### allow-images

Whether images are automatically loaded in web pages.

Valid values:

- `true`

- `false`

Default: `true`

### allow-javascript

Enables or disables the running of JavaScript programs.

Valid values:

- `true`

- `false`

Default: `true`

### allow-plugins

Enables or disables plugins in Web pages.

Qt plugins with a mimetype such as "application/x-qt-plugin" are not affected by this setting.

Valid values:

- `true`

- `false`

Default: `false`

### javascript-can-open-windows

Whether JavaScript programs can open new windows.

Valid values:

- `true`

- `false`

Default: `false`

### javascript-can-close-windows

Whether JavaScript programs can close windows.

Valid values:

- `true`

- `false`

Default: `false`

### javascript-can-access-clipboard

Whether JavaScript programs can read or write to the clipboard.

Valid values:

- `true`

- `false`

Default: `false`

### local-content-can-access-remote-urls

Whether locally loaded documents are allowed to access remote urls.

Valid values:

- `true`

- `false`

Default: `false`

### local-content-can-access-file-urls

Whether locally loaded documents are allowed to access other local urls.

Valid values:

- `true`

- `false`

Default: `true`

### cookies-accept

Whether to accept cookies.

Valid values:

- `default`: Default QtWebKit behaviour.

- `never`: Don’t accept cookies at all.

Default: `default`

### cookies-store

Whether to store cookies.

Valid values:

- `true`

- `false`

Default: `true`

### host-block-lists

List of URLs of lists which contain hosts to block.

The file can be in one of the following formats:

- An /etc/hosts-like file

- One host per line

- A zip-file of any of the above, with either only one file, or a file named hosts (with any extension).

Default: `http://www.malwaredomainlist.com/hostslist/hosts.txt,http://someonewhocares.org/hosts/hosts,http://winhelp2002.mvps.org/hosts.zip,http://malwaredomains.lehigh.edu/files/justdomains.zip,http://pgl.yoyo.org/adservers/serverlist.php?hostformat=hosts&mimetype=plaintext,http://hosts-file.net/ad_servers.asp`

## hints

Hinting settings.

### border

CSS border value for hints.

Default: `1px solid #E3BE23`

### opacity

Opacity for hints.

Default: `0.7`

### mode

Mode to use for hints.

Valid values:

- `number`: Use numeric hints.

- `letter`: Use the chars in the hints → chars setting.

Default: `letter`

### chars

Chars used for hint strings.

Default: `asdfghjkl`

### uppercase

Make chars in hint strings uppercase.

Valid values:

- `true`

- `false`

Default: `false`

### auto-follow

Whether to auto-follow a hint if there’s only one left.

Valid values:

- `true`

- `false`

Default: `true`

### next-regexes

A comma-separated list of regexes to use for next links.

Default: `\bnext\b,\bmore\b,\bnewer\b,\b[>→≫\b,\b(>>|»)\b]`

### prev-regexes

A comma-separated list of regexes to use for prev links.

Default: `\bprev(ious)?\b,\bback\b,\bolder\b,\b[<←≪\b,\b(<<|«)\b]`

## searchengines

Definitions of search engines which can be used via the address bar. The searchengine named `DEFAULT` is used when `general -> auto-search` is true and something else than a URL was entered to be opened. Other search engines can be used via the bang-syntax, e.g. `:open qutebrowser !google`. The string `{}` will be replaced by the search term, use `{{` and `}}` for literal `{`/`}` signs.

## aliases

Aliases for commands. By default, no aliases are defined. Example which adds a new command `:qtb` to open qutebrowsers website:

`qtb = open http://www.qutebrowser.org/`

## colors

Colors used in the UI. A value can be in one of the following format:

- `#RGB`/`#RRGGBB`/`#RRRGGGBBB`/`#RRRRGGGGBBBB`

- A SVG color name as specified in the W3C specification.

- transparent (no color)

- `rgb(r, g, b)` / `rgba(r, g, b, a)` (values 0-255 or percentages)

- `hsv(h, s, v)` / `hsva(h, s, v, a)` (values 0-255, hue 0-359)

- A gradient as explained in the Qt documentation under “Gradient”.

The `hints.*` values are a special case as they’re real CSS colors, not Qt-CSS colors. There, for a gradient, you need to use `-webkit-gradient`, see the WebKit documentation.

### completion.fg

Text color of the completion widget.

Default: `white`

### completion.bg

Background color of the completion widget.

Default: `#333333`

### completion.item.bg

Background color of completion widget items.

Default: `${completion.bg}`

### completion.category.fg

Foreground color of completion widget category headers.

Default: `white`

### completion.category.bg

Background color of the completion widget category headers.

Default: `qlineargradient(x1:0, y1:0, x2:0, y2:1, stop:0 #888888, stop:1 #505050)`

### completion.category.border.top

Top border color of the completion widget category headers.

Default: `black`

### completion.category.border.bottom

Bottom border color of the completion widget category headers.

Default: `${completion.category.border.top}`

### completion.item.selected.fg

Foreground color of the selected completion item.

Default: `black`

### completion.item.selected.bg

Background color of the selected completion item.

Default: `#e8c000`

### completion.item.selected.border.top

Top border color of the completion widget category headers.

Default: `#bbbb00`

### completion.item.selected.border.bottom

Bottom border color of the selected completion item.

Default: `${completion.item.selected.border.top}`

### completion.match.fg

Foreground color of the matched text in the completion.

Default: `#ff4444`

### statusbar.bg

Foreground color of the statusbar.

Default: `black`

### statusbar.fg

Foreground color of the statusbar.

Default: `white`

### statusbar.bg.error

Background color of the statusbar if there was an error.

Default: `red`

### statusbar.bg.prompt

Background color of the statusbar if there is a prompt.

Default: `darkblue`

### statusbar.bg.insert

Background color of the statusbar in insert mode.

Default: `darkgreen`

### statusbar.progress.bg

Background color of the progress bar.

Default: `white`

### statusbar.url.fg

Default foreground color of the URL in the statusbar.

Default: `${statusbar.fg}`

### statusbar.url.fg.success

Foreground color of the URL in the statusbar on successful load.

Default: `lime`

### statusbar.url.fg.error

Foreground color of the URL in the statusbar on error.

Default: `orange`

### statusbar.url.fg.warn

Foreground color of the URL in the statusbar when there’s a warning.

Default: `yellow`

### statusbar.url.fg.hover

Foreground color of the URL in the statusbar for hovered links.

Default: `aqua`

### tabs.fg.odd

Foreground color of unselected odd tabs.

Default: `white`

### tabs.fg.even

Foreground color of unselected even tabs.

Default: `white`

### tabs.fg.selected

Foreground color of selected tabs.

Default: `white`

### tabs.bg.odd

Background color of unselected odd tabs.

Default: `grey`

### tabs.bg.even

Background color of unselected even tabs.

Default: `darkgrey`

### tabs.bg.selected

Background color of selected tabs.

Default: `black`

### tabs.bg.bar

Background color of the tabbar.

Default: `#555555`

### tabs.indicator.start

Color gradient start for the tab indicator.

Default: `#0000aa`

### tabs.indicator.stop

Color gradient end for the tab indicator.

Default: `#00aa00`

### tabs.indicator.error

Color for the tab indicator on errors..

Default: `#ff0000`

### tabs.indicator.system

Color gradient interpolation system for the tab indicator.

Valid values:

- `rgb`: Interpolate in the RGB color system.

- `hsv`: Interpolate in the HSV color system.

- `hsl`: Interpolate in the HSL color system.

Default: `rgb`

### tabs.seperator

Color for the tab seperator.

Default: `#555555`

### hints.fg

Font color for hints.

Default: `black`

### hints.fg.match

Font color for the matched part of hints.

Default: `green`

### hints.bg

Background color for hints.

Default: `-webkit-gradient(linear, left top, left bottom, color-stop(0%,#FFF785), color-stop(100%,#FFC542))`

### downloads.fg

Foreground color for downloads.

Default: `#ffffff`

### downloads.bg.bar

Background color for the download bar.

Default: `black`

### downloads.bg.start

Color gradient start for downloads.

Default: `#0000aa`

### downloads.bg.stop

Color gradient end for downloads.

Default: `#00aa00`

### downloads.bg.system

Color gradient interpolation system for downloads.

Valid values:

- `rgb`: Interpolate in the RGB color system.

- `hsv`: Interpolate in the HSV color system.

- `hsl`: Interpolate in the HSL color system.

Default: `rgb`

### downloads.bg.error

Background color for downloads with errors.

Default: `red`

## fonts

Fonts used for the UI, with optional style/weight/size.

- Style: `normal`/`italic`/`oblique`

- Weight: `normal`, `bold`, `100`..`900`

- Size: number `px`/`pt`

### _monospace

Default monospace fonts.

Default: `Terminus, Monospace, "DejaVu Sans Mono", Monaco, "Bitstream Vera Sans Mono", "Andale Mono", "Liberation Mono", "Courier New", Courier, monospace, Fixed, Consolas, Terminal`

### completion

Font used in the completion widget.

Default: `8pt ${_monospace}`

### tabbar

Font used in the tabbar.

Default: `8pt ${_monospace}`

### statusbar

Font used in the statusbar.

Default: `8pt ${_monospace}`

### downloads

Font used for the downloadbar.

Default: `8pt ${_monospace}`

### hints

Font used for the hints.

Default: `bold 12px Monospace`

### debug-console

Font used for the debugging console.

Default: `8pt ${_monospace}`

### web-family-standard

Font family for standard fonts.

Default: empty

### web-family-fixed

Font family for fixed fonts.

Default: empty

### web-family-serif

Font family for serif fonts.

Default: empty

### web-family-sans-serif

Font family for sans-serif fonts.

Default: empty

### web-family-cursive

Font family for cursive fonts.

Default: empty

### web-family-fantasy

Font family for fantasy fonts.

Default: empty

### web-size-minimum

The hard minimum font size.

Default: empty

### web-size-minimum-logical

The minimum logical font size that is applied when zooming out.

Default: empty

### web-size-default

The default font size for regular text.

Default: empty

### web-size-default-fixed

The default font size for fixed-pitch text.

Default: empty